@@ -3,7 +3,7 @@
 # This script updates Double Commander Open Build Service (OBS) repository
 
 # Set Double Commander version
-DC_VER=0.5.7
+DC_VER=0.5.8
 
 # Temp directory
 DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
@@ -18,7 +18,7 @@ DC_OBS_WEB_DIR=home:Alexx2000
 # OBS project directory
 DC_OBS_PRJ_DIR=$DC_OBS_DIR/$DC_OBS_WEB_DIR
 # DC revision number
-DC_REVISION=$(svnversion -n ../../)
+DC_REVISION=$(svnversion ../../ | sed -e 's/\([0-9]*\).*/\1/')
 
 # Recreate temp directory
 rm -rf $DC_TEMP_DIR
@@ -42,7 +42,7 @@ update_doublecmd()
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
   rm -rf $DC_SOURCE_DIR/doc/ru
-  rm -rf $DC_SOURCE_DIR/doc/uk
+  rm -rf $DC_SOURCE_DIR/doc/uk_UA
 
   # Prepare doublecmd-*.spec file
   cp -a rpm/doublecmd-*.spec $DC_TEMP_DIR
