@@ -3,7 +3,7 @@
 # This script updates Double Commander Personal Package Archive (PPA) repository
 
 # Set Double Commander version
-DC_VER=0.5.7
+DC_VER=0.5.8
 # Set Ubuntu series
 DISTRO=( precise quantal raring saucy )
 
@@ -14,7 +14,7 @@ DC_SOURCE_DIR=$DC_TEMP_DIR/doublecmd-$DC_VER
 # Directory for DC help
 DC_HELP_DIR=$DC_TEMP_DIR/doublecmd-help-$DC_VER
 # DC revision number
-DC_REVISION=$(svnversion -n ../../)
+DC_REVISION=$(svnversion ../../ | sed -e 's/\([0-9]*\).*/\1/')
 
 # Recreate temp directory
 rm -rf $DC_TEMP_DIR
@@ -38,7 +38,7 @@ update_doublecmd()
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
   rm -rf $DC_SOURCE_DIR/doc/ru
-  rm -rf $DC_SOURCE_DIR/doc/uk
+  rm -rf $DC_SOURCE_DIR/doc/uk_UA
 
   # Create doublecmd-x.x.x.orig.tar.gz
   pushd $DC_SOURCE_DIR/..
@@ -54,7 +54,7 @@ update_doublecmd()
   do
     # Update changelog file
     pushd $DC_SOURCE_DIR/debian
-    dch -m -D $DIST -v $DC_VER-$DC_REVISION~$DIST "Update to revision $DC_REVISION"
+    dch -m -D $DIST -v $DC_VER-0+svn$DC_REVISION~$DIST "Update to revision $DC_REVISION"
     popd
 
     # Create archive with source code
@@ -80,7 +80,7 @@ update_doublecmd_svn()
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
   rm -rf $DC_SOURCE_DIR/doc/ru
-  rm -rf $DC_SOURCE_DIR/doc/uk
+  rm -rf $DC_SOURCE_DIR/doc/uk_UA
 
   # Prepare debian directory
   mkdir -p $DC_SOURCE_DIR/debian
@@ -92,7 +92,7 @@ update_doublecmd_svn()
   do
     # Update changelog file
     pushd $DC_SOURCE_DIR/debian
-    dch -m -D $DIST -v $DC_VER-$DC_REVISION~$DIST "Update to revision $DC_REVISION"
+    dch -m -D $DIST -v $DC_VER-0+svn$DC_REVISION~$DIST "Update to revision $DC_REVISION"
     popd
 
     # Create archive with source code
